@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with GWDataFind.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Pytest hooks for gwdatafind
+"""Pytest hooks for gwdatafind.
 """
 
 import warnings
