@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with GWDataFind.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Tests for :mod:`gwdatafind`
+"""Tests for :mod:`gwdatafind`.
 """
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
