@@ -15,7 +15,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-"""Test utilities
+"""Test utilities.
 """
 
 import os
@@ -27,7 +27,7 @@ from . import yield_fixture
 
 @yield_fixture
 def response():
-    """Patch an HTTPConnection to do nothing in particular
+    """Patch an HTTPConnection to do nothing in particular.
 
     Yields the patch for `http.client.HTTPConnection.getresponse`
     """
@@ -38,7 +38,7 @@ def response():
 
 @yield_fixture
 def tmpname():
-    """Return a temporary file name, cleaning up after the method returns
+    """Return a temporary file name, cleaning up after the method returns.
     """
     name = tempfile.mktemp()
     open(name, 'w').close()
