@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with GWDataFind.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Tests for :mod:`gwdatafind.__main__` (the CLI)
+"""Tests for :mod:`gwdatafind.__main__` (the CLI).
 """
 
 import argparse
@@ -37,26 +37,29 @@ URLS = [
     'file:///test/X-test-1-1.gwf',
     'file:///test2/X-test-2-1.gwf',
     'file:///test2/X-test-7-4.gwf',
+    'file:///test/X-test-0-1.h5',
+    'file:///test/X-test-1-1.h5',
 ]
-OUTPUT_URLS = """
+GWF_URLS = [url for url in URLS if url.endswith(".gwf")]
+GWF_OUTPUT_URLS = """
 file:///test/X-test-0-1.gwf
 file:///test/X-test-1-1.gwf
 file:///test2/X-test-2-1.gwf
 file:///test2/X-test-7-4.gwf
 """[1:]  # strip leading line return
-OUTPUT_LAL_CACHE = """
+GWF_OUTPUT_LAL_CACHE = """
 X test 0 1 file:///test/X-test-0-1.gwf
 X test 1 1 file:///test/X-test-1-1.gwf
 X test 2 1 file:///test2/X-test-2-1.gwf
 X test 7 4 file:///test2/X-test-7-4.gwf
 """[1:]
-OUTPUT_NAMES_ONLY = """
+GWF_OUTPUT_NAMES_ONLY = """
 /test/X-test-0-1.gwf
 /test/X-test-1-1.gwf
 /test2/X-test-2-1.gwf
 /test2/X-test-7-4.gwf
 """[1:]
-OUTPUT_OMEGA_CACHE = """
+GWF_OUTPUT_OMEGA_CACHE = """
 X test 0 2 1 file:///test
 X test 2 3 1 file:///test2
 X test 7 11 4 file:///test2
@@ -85,13 +88,11 @@ def test_command_line():
     assert args.server == 'something'
 
 
-@mock.patch.dict('os.environ')
+@mock.patch.dict('os.environ', clear=True)
 @pytest.mark.parametrize('defserv', (None, 'test.datafind.com:443'))
 def test_command_line_server(defserv):
     if defserv:
         os.environ['GWDATAFIND_SERVER'] = defserv
-    else:
-        os.environ.pop('GWDATAFIND_SERVER', None)
     parser = main.command_line()
     serveract = [act for act in parser._actions if act.dest == 'server'][0]
     assert serveract.required is (not defserv)
@@ -118,10 +119,16 @@ def test_sanity_check_fail(clargs):
 
 @mock.patch('gwdatafind.ui.ping')
 def test_ping(mping):
-    args = argparse.Namespace(server='test.datafind.com:443')
+    args = argparse.Namespace(
+        server='test.datafind.com:443',
+        extension='gwf',
+    )
     out = StringIO()
     main.ping(args, out)
-    assert mping.called_with(host=args.server)
+    mping.assert_called_with(
+        host=args.server,
+        ext=args.extension,
+    )
     out.seek(0)
     assert out.read().rstrip() == (
         'LDRDataFindServer at test.datafind.com:443 is alive')
@@ -132,12 +139,17 @@ def test_show_observatories(mfindobs):
     mfindobs.return_value = ['A', 'B', 'C']
     args = argparse.Namespace(
         server='test.datafind.com:443',
+        extension='gwf',
         match='test',
     )
     out = StringIO()
     main.show_observatories(args, out)
     out.seek(0)
-    assert mfindobs.called_with(host=args.server, match=args.match)
+    mfindobs.assert_called_with(
+        host=args.server,
+        match=args.match,
+        ext=args.extension,
+    )
     assert list(map(str.rstrip, out.readlines())) == ['A', 'B', 'C']
 
 
@@ -146,14 +158,19 @@ def test_show_types(mfindtypes):
     mfindtypes.return_value = ['A', 'B', 'C']
     args = argparse.Namespace(
         server='test.datafind.com:443',
+        extension='gwf',
         observatory='X',
         match='test',
     )
     out = StringIO()
     main.show_types(args, out)
     out.seek(0)
-    assert mfindtypes.called_with(host=args.server, match=args.match,
-                                  site=args.observatory)
+    mfindtypes.assert_called_with(
+        host=args.server,
+        match=args.match,
+        site=args.observatory,
+        ext=args.extension,
+    )
     assert list(map(str.rstrip, out.readlines())) == ['A', 'B', 'C']
 
 
@@ -162,6 +179,7 @@ def test_show_times(mfindtimes):
     mfindtimes.return_value = [segment(0, 1), segment(1, 2), segment(3, 4)]
     args = argparse.Namespace(
         server='test.datafind.com:443',
+        extension='gwf',
         observatory='X',
         type='test',
         gpsstart=0,
@@ -169,9 +187,14 @@ def test_show_times(mfindtimes):
     )
     out = StringIO()
     main.show_times(args, out)
-    assert mfindtimes.called_with(host=args.server, site=args.observatory,
-                                  frametype=args.type, gpsstart=args.gpsstart,
-                                  gpsend=args.gpsend)
+    mfindtimes.assert_called_with(
+        host=args.server,
+        site=args.observatory,
+        frametype=args.type,
+        gpsstart=args.gpsstart,
+        gpsend=args.gpsend,
+        ext=args.extension,
+    )
     out.seek(0)
     for i, line in enumerate(out.readlines()[1:]):
         seg = mfindtimes.return_value[i]
@@ -183,19 +206,23 @@ def test_latest(mlatest):
     mlatest.return_value = ['file:///test/X-test-0-10.gwf']
     args = argparse.Namespace(
         server='test.datafind.com:443',
+        extension='gwf',
         observatory='X',
         type='test',
         url_type='file',
-        lal_cache=False,
-        names_only=False,
-        frame_cache=False,
+        format="urls",
         gaps=None,
     )
     out = StringIO()
     main.latest(args, out)
-    assert mlatest.called_with(args.observatory, args.type,
-                               urltype=args.url_type, on_missing='warn',
-                               host=args.server)
+    mlatest.assert_called_with(
+        args.observatory,
+        args.type,
+        urltype=args.url_type,
+        on_missing='warn',
+        host=args.server,
+        ext=args.extension,
+    )
     out.seek(0)
     assert out.read().rstrip() == mlatest.return_value[0]
 
@@ -208,66 +235,77 @@ def test_filename(mfindurl):
         filename='X-test-0-10.gwf',
         url_type='file',
         type=None,
-        lal_cache=False,
-        names_only=False,
-        frame_cache=False,
+        format="urls",
         gaps=None,
     )
     out = StringIO()
     main.filename(args, out)
-    assert mfindurl.called_with(args.filename, urltype=args.url_type,
-                                on_missing='warn', host=args.server)
+    mfindurl.assert_called_with(
+        args.filename,
+        urltype=args.url_type,
+        on_missing='warn',
+        host=args.server,
+    )
     out.seek(0)
     assert out.read().rstrip() == mfindurl.return_value[0]
 
 
 @mock.patch('gwdatafind.ui.find_urls')
-def test_show_urls(mfindurls):
-    mfindurls.return_value = URLS
+@pytest.mark.parametrize("ext", [
+    "gwf",
+    "h5",
+])
+def test_show_urls(mfindurls, ext):
+    urls = [x for x in URLS if x.endswith(f".{ext}")]
+    mfindurls.return_value = urls
     args = argparse.Namespace(
         server='test.datafind.com:443',
+        extension=ext,
         observatory='X',
         type='test',
         gpsstart=0,
         gpsend=10,
         url_type='file',
         match=None,
-        lal_cache=False,
-        names_only=False,
-        frame_cache=False,
+        format="urls",
         gaps=None,
     )
     out = StringIO()
     main.show_urls(args, out)
-    assert mfindurls.called_with(args.observatory, args.type, args.gpsstart,
-                                 args.gpsend, match=args.match,
-                                 urltype=args.url_type, on_gaps='ignore',
-                                 host=args.server)
+    mfindurls.assert_called_with(
+        args.observatory,
+        args.type,
+        args.gpsstart,
+        args.gpsend,
+        match=args.match,
+        urltype=args.url_type,
+        on_gaps='ignore',
+        ext=ext,
+        host=args.server,
+    )
     out.seek(0)
-    assert list(map(str.rstrip, out.readlines())) == URLS
+    assert list(map(str.rstrip, out.readlines())) == urls
 
 
 @pytest.mark.parametrize('fmt,result', [
-    (None, OUTPUT_URLS),
-    ('lal_cache', OUTPUT_LAL_CACHE),
-    ('names_only', OUTPUT_NAMES_ONLY),
-    ('frame_cache', OUTPUT_OMEGA_CACHE),
+    ("urls", GWF_OUTPUT_URLS),
+    ("lal", GWF_OUTPUT_LAL_CACHE),
+    ("names", GWF_OUTPUT_NAMES_ONLY),
+    ("omega", GWF_OUTPUT_OMEGA_CACHE),
 ])
 def test_postprocess_cache_format(fmt, result):
     # create namespace for parsing
     args = argparse.Namespace(
         type=None,
-        lal_cache=False,
+        format=fmt,
         names_only=False,
         frame_cache=False,
         gaps=None,
     )
-    if fmt:
-        setattr(args, fmt, True)
 
     # run
     out = StringIO()
-    assert not main.postprocess_cache(URLS, args, out)
+    assert not main.postprocess_cache(GWF_URLS, args, out)
     out.seek(0)
     assert out.read() == result
 
@@ -275,15 +313,13 @@ def test_postprocess_cache_format(fmt, result):
 def test_postprocess_cache_sft():
     args = argparse.Namespace(
         type='TEST_1800SFT',
-        lal_cache=False,
-        names_only=False,
-        frame_cache=False,
+        format=None,
         gaps=None,
     )
     out = StringIO()
-    main.postprocess_cache(URLS, args, out)
+    main.postprocess_cache(GWF_URLS, args, out)
     out.seek(0)
-    assert out.read() == OUTPUT_URLS.replace('.gwf', '.sft')
+    assert out.read() == GWF_OUTPUT_URLS.replace('.gwf', '.sft')
 
 
 def test_postprocess_cache_gaps(capsys):
@@ -291,17 +327,14 @@ def test_postprocess_cache_gaps(capsys):
         gpsstart=0,
         gpsend=10,
         type=None,
-        lal_cache=False,
-        names_only=False,
-        frame_cache=False,
+        format=None,
         gaps=True,
     )
     out = StringIO()
     assert main.postprocess_cache(URLS, args, out) == 1
     _, err = capsys.readouterr()
-    assert err == 'Missing segments:\n\n{0}\n'.format(
-        '\n'.join('{0[0]:d} {0[1]:d}'.format(seg) for seg in GAPS),
-    )
+    segs = "\n".join(f"{seg[0]:d} {seg[1]:d}" for seg in GAPS)
+    assert err == "Missing segments:\n\n{}\n".format(segs)
 
     args.gpsstart = 4
     args.gpsend = 7
@@ -319,11 +352,11 @@ def test_postprocess_cache_gaps(capsys):
     (['-o', 'X', '-t', 'test', '-s', '0', '-e', '10'], 'show_urls'),
 ])
 def test_main(args, patch, tmpname):
-    with mock.patch('gwdatafind.__main__.{0}'.format(patch)) as mocked:
+    with mock.patch(f"gwdatafind.__main__.{patch}") as mocked:
         main.main(args)
         assert mocked.call_count == 1
     # call again with output file
     args.extend(('--output-file', tmpname))
-    with mock.patch('gwdatafind.__main__.{0}'.format(patch)) as mocked:
+    with mock.patch(f"gwdatafind.__main__.{patch}") as mocked:
         main.main(args)
         assert mocked.call_count == 1
